# Uniscan (redirect)

The `uniscan` package has been renamed to [`usentinel`](https://pypi.org/project/usentinel/).

This release is a compatibility shim that depends on `usentinel>=0.2.0` and re-exports its APIs.
Please update your dependencies to refer to `usentinel` directly.
